@@ -1,8 +1,6 @@
 from diffgram.file.file import File
 from ..regular.regular import refresh_from_dict
 import logging
-from diffgram.pytorch_diffgram.diffgram_pytorch_dataset import DiffgramPytorchDataset
-from diffgram.tensorflow_diffgram.diffgram_tensorflow_dataset import DiffgramTensorflowDataset
 from diffgram.core.diffgram_dataset_iterator import DiffgramDatasetIterator
 from multiprocessing.pool import ThreadPool as Pool
 
@@ -101,20 +99,23 @@ class Directory(DiffgramDatasetIterator):
             result = result + diffgram_files
         return result
 
-    def all_file_ids(self):
+    def all_file_ids(self, query = None):
         page_num = 1
         result = []
 
-        diffgram_ids = self.list_files(limit = 5000, page_num = page_num, file_view_mode = 'ids_only')
+        diffgram_ids = self.list_files(limit = 5000, page_num = page_num, file_view_mode = 'ids_only', query = query)
+        if diffgram_ids is False:
+            raise Exception('Error Fetching Files: Please check you are providing a valid query.')
         result = result + diffgram_ids
         page_num = self.file_list_metadata['next_page']
         total_pages = self.file_list_metadata['total_pages']
         pool = Pool(20)
 
         pool_results = []
-        for i in range(page_num, total_pages + 1):
-            result_async = pool.apply_async(self.list_files, (i, 5000, None, 'ids_only', None))
-            pool_results.append(result_async)
+        if page_num is not None:
+            for i in range(page_num, total_pages + 1):
+                result_async = pool.apply_async(self.list_files, (i, 5000, None, 'ids_only', None))
+                pool_results.append(result_async)
 
         for pool_result in pool_results:
             file_ids = pool_result.get()
@@ -152,6 +153,7 @@ class Directory(DiffgramDatasetIterator):
             Transforms the file list inside the dataset into a pytorch dataset.
         :return:
         """
+        from diffgram.pytorch_diffgram.diffgram_pytorch_dataset import DiffgramPytorchDataset
         file_id_list = self.file_id_list
         pytorch_dataset = DiffgramPytorchDataset(
             project = self.client,
@@ -163,6 +165,7 @@ class Directory(DiffgramDatasetIterator):
         return pytorch_dataset
 
     def to_tensorflow(self):
+        from diffgram.tensorflow_diffgram.diffgram_tensorflow_dataset import DiffgramTensorflowDataset
         file_id_list = self.file_id_list
         diffgram_tensorflow_dataset = DiffgramTensorflowDataset(
             project = self.client,
